==> eec-0.5.10-sources.jar: org/ttzero/excel/entity/style/BuildInColor.java <==
/*
 * Copyright (c) 2017-2023, guanquan.wang@yandex.com All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package org.ttzero.excel.entity.style;

import java.awt.Color;

/**
 * OpenXML build in color
 *
 * @author guanquan.wang at 2023-01-18 16:51
 */
public class BuildInColor extends Color {
    // OpenXML color index
    private final int indexed;

    public BuildInColor(int indexed) {
        // Approximate processing, when indexed greater than 64 means automatic
        super(indexed >=0 && indexed < 64 ? ColorIndex.colors[indexed] : 0);
        this.indexed = indexed;
    }

    public int getIndexed() {
        return indexed;
    }

//    @Override
//    public int hashCode() {
//        return indexed;
//    }
//
//    @Override
//    public boolean equals(Object o) {
//        return o instanceof BuildInColor && ((BuildInColor) o).indexed == indexed;
//    }

    @Override
    public String toString() {
        return "Color indexed=\"" + indexed + "\"" + " [r=" + getRed() + ",g=" + getGreen() + ",b=" + getBlue() + "]";
    }
}

==> eec-0.5.13-sources.jar: org/ttzero/excel/entity/style/BuildInColor.java <==
/*
 * Copyright (c) 2017-2023, guanquan.wang@yandex.com All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package org.ttzero.excel.entity.style;

import java.awt.Color;

/**
 * OpenXML build in color
 *
 * @author guanquan.wang at 2023-01-18 16:51
 */
public class BuildInColor extends Color {
    // OpenXML color index
    private final int indexed;

    public BuildInColor(int indexed) {
        // Approximate processing, when indexed greater than 64 means automatic
        super(indexed >=0 && indexed < 64 ? ColorIndex.indexedColors[indexed] : 0);
        this.indexed = indexed;
    }

    public int getIndexed() {
        return indexed;
    }

//    @Override
//    public int hashCode() {
//        return indexed;
//    }
//
//    @Override
//    public boolean equals(Object o) {
//        return o instanceof BuildInColor && ((BuildInColor) o).indexed == indexed;
//    }

    @Override
    public String toString() {
        return "Color indexed=\"" + indexed + "\"" + " [r=" + getRed() + ",g=" + getGreen() + ",b=" + getBlue() + "]";
    }
}
